import { Program } from '@project-serum/anchor';
import { Connection } from '@solana/web3.js';
import { ChainId, ChainsConfig, Contracts, Network, Platform, VAA, WormholeCore, WormholeMessageId } from '@wormhole-foundation/connect-sdk';
import { AnySolanaAddress, SolanaChains, SolanaPlatformType, SolanaUnsignedTransaction } from '@wormhole-foundation/connect-sdk-solana';
import { Wormhole as WormholeCoreContract } from './types';
export declare class SolanaWormholeCore<N extends Network, C extends SolanaChains> implements WormholeCore<N, SolanaPlatformType, C> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts;
    readonly chainId: ChainId;
    readonly coreBridge: Program<WormholeCoreContract>;
    readonly address: string;
    constructor(network: N, chain: C, connection: Connection, contracts: Contracts);
    static fromRpc<N extends Network>(connection: Connection, config: ChainsConfig<N, Platform>): Promise<SolanaWormholeCore<N, SolanaChains>>;
    publishMessage(sender: AnySolanaAddress, message: string | Uint8Array): AsyncGenerator<SolanaUnsignedTransaction<N, C>>;
    postVaa(sender: AnySolanaAddress, vaa: VAA, blockhash: string): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    parseTransaction(txid: string): Promise<WormholeMessageId[]>;
    private createUnsignedTx;
}
//# sourceMappingURL=core.d.ts.map